/*
 * Copyright © 2021-2022 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of ipspiel22-demo.
 *
 * Ipspiel22-demo is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Ipspiel22-demo is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with ipspiel22-demo. If not, see
 * <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.ipspiel22.demo.strategy;

import java.util.Optional;

import de.fhdw.gaming.ipspiel22.demo.domain.DemoPlayer;
import de.fhdw.gaming.ipspiel22.demo.domain.DemoState;
import de.fhdw.gaming.ipspiel22.demo.domain.DemoStrategy;
import de.fhdw.gaming.ipspiel22.demo.moves.DemoMove;
import de.fhdw.gaming.ipspiel22.demo.moves.factory.DemoMoveFactory;

/**
 * Implements {@link DemoStrategy} by always saying "no".
 */
public final class DemoSayNoStrategy implements DemoStrategy {

    /**
     * The factory for creating Demo moves.
     */
    private final DemoMoveFactory moveFactory;

    /**
     * Creates an {@link DemoSayNoStrategy}.
     *
     * @param moveFactory The factory for creating Demo moves.
     */
    DemoSayNoStrategy(final DemoMoveFactory moveFactory) {
        this.moveFactory = moveFactory;
    }

    @Override
    public Optional<DemoMove> computeNextMove(final int gameId, final DemoPlayer player, final DemoState state) {
        return Optional.of(this.moveFactory.createNoMove());
    }

    @Override
    public String toString() {
        return DemoSayNoStrategy.class.getSimpleName();
    }
}
